# workbooky

A module providing utilities to work with EXce; workbooks and worksheets.

## Installation

```bash
pip install workbooky
```

## Usage

```python
from workbooky import Workbook

workbook = Workbook(path)
```

## Methods

```python
get_worksheet(sheet_name)
```

```python
save()
```

